import "neuralynx_defs";

global int filter = @toint(@arg("filter","0"));   // should spike files be filtered
global int clean  = @toint(@arg("clean","0"));   // number of common files to each sim

tracef("Running Neuralynx usecase1 with filter %i and clean %i\n", filter, clean);

type dummy;

(dummy wait) processDataSet (string dataset, spikefile[] spikefiles) { 
	timestampfile allt[];

	foreach f in spikefiles {
		string[] tnames;

		if (filter == 1) {
			spikefile filteredf <regexp_mapper;
					source=@filename(f),
					match="(.*)(N[ST][ET])",
					transform="\\1filtered.\\2">;

			filteredf = filter(f);

			tnames[0] = @regexp(@filename(f), ".N[ST][ET]", ".filtered.1.T");
			tnames[1] = @regexp(@filename(f), ".N[ST][ET]", ".filtered.2.T");
			tnames[2] = @regexp(@filename(f), ".N[ST][ET]", ".filtered.4.T");
	
			timestampfile t[] <array_mapper;files=tnames>;

			t = spikesort(filteredf);
		}
		else {
			tnames[0] = @regexp(@filename(f), ".N[ST][ET]", ".1.T");
			tnames[1] = @regexp(@filename(f), ".N[ST][ET]", ".2.T");
			tnames[2] = @regexp(@filename(f), ".N[ST][ET]", ".4.T");
	
			timestampfile t[] <array_mapper;files=tnames>;

			t = spikesort(f);
		}
	}

	if (clean == 1) {
		nvt pos <filesys_mapper;location=dataset, suffix=".NVT">;

		nvt cleanpos <regexp_mapper;
				source=@filename(pos),
				match="(.*)(NVT)",
				transform="\\1cleaned.\\2">;

		cleanpos = clean(pos);
	}
}

(dataminefile d) waitThenMine (string dataset, dummy a, dummy b, dummy c) {
	timestampfile[] t <filesys_mapper;location=dataset, suffix=".T">;

	nvt pos <filesys_mapper;location="firstdataset", suffix=".NVT">;

	nev ev <filesys_mapper;location="firstdataset", suffix=".NEV">;

	d = datamine(ev, pos, t);
}

string[] datasets = readData("datasets.txt");

foreach dataset in datasets {
	spikefile[] nses <filesys_mapper;location=dataset, suffix=".NSE">;
	spikefile[] nsts <filesys_mapper;location=dataset, suffix=".NST">;
	spikefile[] ntts <filesys_mapper;location=dataset, suffix=".NTT">;

	dummy waitnse;
	dummy waitnst;
	dummy waitntt;

	waitnse = processDataSet(dataset, nses);
	waitnst = processDataSet(dataset, nsts);
	waitntt = processDataSet(dataset, ntts);

	dataminefile d <simple_mapper;location=dataset, prefix="datamine", suffix=".txt">;

	//FIXME: why does this complain of casting integer to string?
	//d = waitThenMine(dataset, waitnse, waitnst, waitntt);
	tracef("DEBUG: dataset %s, dataminefile %M, waitnse %M, waitnst %M, waitntt %M", dataset, d, waitnse, waitnst, waitntt);
}
